# Copyright 2005 Lars Wirzenius (liw@iki.fi)
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA


"""Register all address commands."""


import eoc.exceptions


class IncorrectHashSpecification(eoc.exceptions.EocException):

    def __init__(self, name, has_hash):
        self.str = ("Address command hash specification %s conflicts " +
                    "with previous setting for command %s") % (name, has_hash)


class AddressCommand:

    def __init__(self, name, has_hash):
        self.name = name
        self.has_hash = has_hash
        self.callbacks = []
        
    def add_callback(self, callback):
        if callback not in self.callbacks:
            self.callbacks.append(callback)

    def __call__(self, mlm, ml, sender, parts, msg):
        for callback in self.callbacks:
            if callback(mlm, ml, sender, parts, msg):
                break


class AddressCommands:

    def __init__(self):
        self.commands = {}
    
    def add_command(self, name, has_hash, callback):
        if name in self.commands:
            if (not has_hash) != (not self.commands[name].has_hash):
                raise IncorrectHashSpecification(name, has_hash)
        else:
            self.commands[name] = AddressCommand(name, has_hash)
        self.commands[name].add_callback(callback)

    def all_commands(self):
        return self.commands.keys()

    def hash_commands(self):
        return [c.name for c in self.commands.values() if c.has_hash]

    def __getitem__(self, name):
        return self.commands[name]
