# Copyright 2005 Lars Wirzenius (liw@iki.fi)
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA


"""Set up logging."""


import logging
import sys
import time


class IndentedFormatter(logging.Formatter):
    
    def format(self, record):
        str = logging.Formatter.format(self, record)
        return "\n  ".join(str.split("\n"))

    def formatTime(self, record, datefmt=None):
        if datefmt is None:
            datefmt = "%Y-%m-%d %H:%M:%S"
        return time.strftime(datefmt)

def setup(filenames):
    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)
    
    formatter = IndentedFormatter("%(asctime)s %(levelname)s: %(message)s")
    
    handler = logging.StreamHandler(sys.stdout)
    global _stdout_handler
    _stdout_handler = handler
    handler.setFormatter(formatter)
    handler.setLevel(logging.DEBUG)
    logger.addHandler(handler)

    for filename in filenames:
        handler = logging.FileHandler(filename)
        handler.setFormatter(formatter)
        handler.setLevel(logging.DEBUG)
        logger.addHandler(handler)


def set_stdout_debug(*args):
    """Set logging to stdout to happend at the logging.DEBUG level"""
    _stdout_handler.setLevel(logging.DEBUG)
