# Copyright 2005 Lars Wirzenius (liw@iki.fi)
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA


"""Subscriber database."""


class SubscriberDB:

    """A subscriber database for a mailing list."""
    
    def __init__(self, store):
        self._store = store
        self._store.lock()
        self._store.commit()
        
    def list(self):
        """List all subscriber addresses."""
        return self._store.get_items()
        
    def has(self, address):
        """Is address subscribed?"""
        return address in self.list()
        
    def add(self, address):
        """Add address as subscriber, unless already is."""
        self._store.lock()
        self._store.set_value(address, "foo", "bar")
        self._store.commit()

    def remove(self, address):
        """Remove an address from the subscribers, if it is there."""
        self._store.lock()
        self._store.remove_item(address)
        self._store.commit()

    def reload(self):
        """Re-load the contents of the database."""
        self._store.reload()
